@@ -27,6 +27,7 @@ backgrounds::~backgrounds()
 
 void backgrounds::on_clock_clicked()
 {
+    QMaemo5InformationBox::information(this, tr("Select image"), QMaemo5InformationBox::DefaultTimeout);
     const QString COLOR_STYLE("QPushButton { border-image: url(%2); border: 2px solid white; }");
     QString clockdir2 = QFileDialog::getOpenFileName(this, "Select Image", lastpath, "Images (*.jpeg *.jpg *.gif *.png *.bmp *.tiff)");
     if (clockdir2.isEmpty()) return;
@@ -39,6 +40,7 @@ void backgrounds::on_clock_clicked()
 
 void backgrounds::on_appmanager_clicked()
 {
+    QMaemo5InformationBox::information(this, tr("Select image"), QMaemo5InformationBox::DefaultTimeout);
     const QString COLOR_STYLE("QPushButton { border-image: url(%2); border: 2px solid white; }");
     QString appdir2 = QFileDialog::getOpenFileName(this, "Select Image", lastpath, "Images (*.jpeg *.jpg *.gif *.png *.bmp *.tiff)");
     if (appdir2.isEmpty()) return;
@@ -51,6 +53,7 @@ void backgrounds::on_appmanager_clicked()
 
 void backgrounds::on_mplayer_clicked()
 {
+    QMaemo5InformationBox::information(this, tr("Select image"), QMaemo5InformationBox::DefaultTimeout);
     const QString COLOR_STYLE("QPushButton { border-image: url(%2); border: 2px solid white; }");
     QString mdir2 = QFileDialog::getOpenFileName(this, "Select Image", lastpath, "Images (*.jpeg *.jpg *.gif *.png *.bmp *.tiff)");
     if (mdir2.isEmpty()) return;
@@ -63,6 +66,7 @@ void backgrounds::on_mplayer_clicked()
 
 void backgrounds::on_lock_clicked()
 {
+    QMaemo5InformationBox::information(this, tr("Select image"), QMaemo5InformationBox::DefaultTimeout);
     const QString COLOR_STYLE("QPushButton { border-image: url(%2); border: 2px solid white; }");
     QString ldir2 = QFileDialog::getOpenFileName(this, "Select Image", lastpath, "Images (*.jpeg *.jpg *.gif *.png *.bmp *.tiff)");
     if (ldir2.isEmpty()) return;
@@ -84,7 +88,8 @@ void backgrounds::on_clockset_clicked()
     args << "changeimagepushed" << "clock.png";
     QProcess *jau = new QProcess(this);
     jau->start("/sbin/launchcustomizer", args);
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
+    jau->waitForFinished();
+    QMaemo5InformationBox::information(this, tr("Image saved!"), QMaemo5InformationBox::DefaultTimeout);
 }
 
 void backgrounds::on_appmanagerset_clicked()
@@ -98,7 +103,8 @@ void backgrounds::on_appmanagerset_clicked()
     args << "changeimagepushed" << "appmanager.png";
     QProcess *jau = new QProcess(this);
     jau->start("/sbin/launchcustomizer", args);
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
+    jau->waitForFinished();
+    QMaemo5InformationBox::information(this, tr("Image saved!"), QMaemo5InformationBox::DefaultTimeout);
 }
 
 void backgrounds::on_mplayerset_clicked()
@@ -112,7 +118,8 @@ void backgrounds::on_mplayerset_clicked()
     args << "changeimagepushed" << "mplayer.png";
     QProcess *jau = new QProcess(this);
     jau->start("/sbin/launchcustomizer", args);
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
+    jau->waitForFinished();
+    QMaemo5InformationBox::information(this, tr("Image saved!"), QMaemo5InformationBox::DefaultTimeout);
 }
 
 void backgrounds::on_lockset_2_clicked()
@@ -126,5 +133,6 @@ void backgrounds::on_lockset_2_clicked()
     args << "changeimagepushed" << "lock.png";
     QProcess *jau = new QProcess(this);
     jau->start("/sbin/launchcustomizer", args);
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
+    jau->waitForFinished();
+    QMaemo5InformationBox::information(this, tr("Image saved!"), QMaemo5InformationBox::DefaultTimeout);
 }
