@@ -429,7 +429,7 @@ void MainWindow::on_pushButton_clicked()
         if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
 
             progress.setLabelText(tr("Restarting services..."));
-            QMaemo5InformationBox::information(this, tr("Restarting services..."), QMaemo5InformationBox::DefaultTimeout);
+            QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."));
             system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
             system("sleep 2");
             system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
