@@ -18,6 +18,11 @@
         <source>Menu bar opacity</source>
         <translation>Yläpalkin näkyvyys</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
+        <translation>Uudelleenkäynnistetään palveluja, näyttö vilkkuu! Laitteen uudelleenkäynnistys prosessin jälkeen on suositeltavaa.</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Theme Customizer - restore files</source>
@@ -408,6 +413,21 @@
         <source>Backgrounds</source>
         <translation>Taustakuvat</translation>
     </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Select image</source>
+        <translation>Valitse kuva</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Processing image</source>
+        <translation>Käsitellään kuvaa</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Image saved!</source>
+        <translation>Kuva tallennettu!</translation>
+    </message>
 </context>
 <context>
     <name>savepreset</name>
