@@ -23,6 +23,11 @@
         <source>Creating backups...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>You must give name for the preset.</source>
@@ -408,6 +413,21 @@
         <source>Backgrounds</source>
         <translation>Fondos</translation>
     </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Select image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Processing image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Image saved!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>savepreset</name>
